@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.c 5742 2007-07-25 14:02:26Z jessevdk $
+ * $Id: gedit-utils.c 5989 2007-10-28 15:00:30Z sfre $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -373,9 +373,15 @@ gedit_utils_escape_search_text (const gchar* text)
 
     	length = strlen (text);
 
+	/* no escape when typing.
+	 * The short circuit works only for ascii, but we only
+	 * care about not escaping a single '\' */
+	if (length == 1)
+		return g_strdup (text);
+
 	str = g_string_new ("");
 
-  	p = text;
+	p = text;
   	end = text + length;
 
   	while (p != end)
@@ -394,6 +400,9 @@ gedit_utils_escape_search_text (const gchar* text)
 			case '\t':
           			g_string_append (str, "\\t");
           			break;
+			case '\\':
+          			g_string_append (str, "\\\\");
+          			break;
         		default:
           			g_string_append_len (str, p, next - p);
           			break;
@@ -559,7 +568,6 @@ gedit_warning (GtkWindow *parent, const gchar *format, ...)
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 
 	g_signal_connect (G_OBJECT (dialog),
 			  "response",
@@ -611,43 +619,6 @@ gedit_utils_escape_underscores (const gchar* text,
 	return g_string_free (str, FALSE);
 }
 
-/*
- * Replaces '/' with '-' to avoid problems in xml paths.
- */
-gchar *
-gedit_utils_escape_slashes (const gchar *text,
-			    gssize       length)
-{
-	GString *str;
-	const gchar *p;
-	const gchar *end;
-
-	g_return_val_if_fail (text != NULL, NULL);
-
-	if (length < 0)
-		length = strlen (text);
-
-	str = g_string_sized_new (length);
-
-	p = text;
-	end = text + length;
-
-	while (p != end)
-	{
-		const gchar *next;
-		next = g_utf8_next_char (p);
-
-		if (*p == '/')
-			g_string_append (str, "-");
-		else
-			g_string_append_len (str, p, next - p);
-
-		p = next;
-	}
-
-	return g_string_free (str, FALSE);
-}
-
 /* the following functions are taken from eel */
 
 gchar *
@@ -825,6 +796,7 @@ gedit_utils_get_current_workspace (GdkScreen *screen)
 	gulong nitems;
 	gulong bytes_after;
 	guint *current_desktop;
+	gint err, result;
 	guint ret = 0;
 
 	g_return_val_if_fail (GDK_IS_SCREEN (screen), 0);
@@ -832,18 +804,20 @@ gedit_utils_get_current_workspace (GdkScreen *screen)
 	root_win = gdk_screen_get_root_window (screen);
 	display = gdk_screen_get_display (screen);
 
-	XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
-			    gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
-			    0, G_MAXLONG,
-			    False, XA_CARDINAL, &type, &format, &nitems,
-			    &bytes_after, (gpointer)&current_desktop);
+	gdk_error_trap_push ();
+	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
+				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_CURRENT_DESKTOP"),
+				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+				     &bytes_after, (gpointer) &current_desktop);
+	err = gdk_error_trap_pop ();
+
+	if (err != Success || result != Success)
+		return ret;
 
 	if (type == XA_CARDINAL && format == 32 && nitems > 0)
-	{
 		ret = current_desktop[0];
-		XFree (current_desktop);
-	}
 
+	XFree (current_desktop);
 	return ret;
 }
 
@@ -864,6 +838,7 @@ gedit_utils_get_window_workspace (GtkWindow *gtkwindow)
 	gulong nitems;
 	gulong bytes_after;
 	guint *workspace;
+	gint err, result;
 	guint ret = GEDIT_ALL_WORKSPACES;
 
 	g_return_val_if_fail (GTK_IS_WINDOW (gtkwindow), 0);
@@ -872,19 +847,73 @@ gedit_utils_get_window_workspace (GtkWindow *gtkwindow)
 	window = GTK_WIDGET (gtkwindow)->window;
 	display = gdk_drawable_get_display (window);
 
-	XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
-			    gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_DESKTOP"),
-			    0, G_MAXLONG,
-			    False, XA_CARDINAL, &type, &format, &nitems,
-			    &bytes_after, (gpointer)&workspace);
+	gdk_error_trap_push ();
+	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (window),
+				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_DESKTOP"),
+				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+				     &bytes_after, (gpointer) &workspace);
+	err = gdk_error_trap_pop ();
+
+	if (err != Success || result != Success)
+		return ret;
 
 	if (type == XA_CARDINAL && format == 32 && nitems > 0)
-	{
 		ret = workspace[0];
-		XFree (workspace);
+
+	XFree (workspace);
+	return ret;
+}
+
+/**
+ * gedit_utils_get_current_viewport: Get the current viewport origin
+ *
+ * Get the currently visible viewport origin for the #GdkScreen.
+ *
+ * If the X11 window property isn't found, (0, 0) is returned.
+ */
+void
+gedit_utils_get_current_viewport (GdkScreen    *screen,
+				  gint         *x,
+				  gint         *y)
+{
+	GdkWindow *root_win;
+	GdkDisplay *display;
+	Atom type;
+	gint format;
+	gulong nitems;
+	gulong bytes_after;
+	gulong *coordinates;
+	gint err, result;
+
+	g_return_if_fail (GDK_IS_SCREEN (screen));
+	g_return_if_fail (x != NULL && y != NULL);
+
+	/* Default values for the viewport origin */
+	*x = 0;
+	*y = 0;
+
+	root_win = gdk_screen_get_root_window (screen);
+	display = gdk_screen_get_display (screen);
+
+	gdk_error_trap_push ();
+	result = XGetWindowProperty (GDK_DISPLAY_XDISPLAY (display), GDK_WINDOW_XID (root_win),
+				     gdk_x11_get_xatom_by_name_for_display (display, "_NET_DESKTOP_VIEWPORT"),
+				     0, G_MAXLONG, False, XA_CARDINAL, &type, &format, &nitems,
+				     &bytes_after, (void*) &coordinates);
+	err = gdk_error_trap_pop ();
+
+	if (err != Success || result != Success)
+		return;
+
+	if (type != XA_CARDINAL || format != 32 || nitems < 2)
+	{
+		XFree (coordinates);
+		return;
 	}
 
-	return ret;
+	*x = coordinates[0];
+	*y = coordinates[1];
+	XFree (coordinates);
 }
 
 void
@@ -1002,11 +1031,14 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 		label = gtk_label_new (msg);
 
 		gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		
 		g_free (filename_markup);
 		g_free (msg_plain);
 		g_free (msg);
 
+		gtk_misc_set_padding (GTK_MISC (label), 5, 5);
+ 		
 		*error_widget = label;
 
 		return FALSE;
@@ -1021,6 +1053,10 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 		*wid = glade_xml_get_widget (gui, name);
 		if (*wid == NULL)
 		{
+			g_warning ("Cannot find widget '%s' inside file '%s'.",
+				   name,
+				   filename);
+				   
 			filename_markup = g_markup_printf_escaped ("<i>%s</i>", filename);
 			msg_plain = g_strdup_printf (
 					_("Unable to find the required widgets inside file %s."),
@@ -1031,11 +1067,14 @@ gedit_utils_get_glade_widgets (const gchar *filename,
 			label = gtk_label_new (msg);
 
 			gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
-
+			gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+			
 			g_free (filename_markup);
 			g_free (msg_plain);
 			g_free (msg);
 
+			gtk_misc_set_padding (GTK_MISC (label), 5, 5);
+ 			
 			*error_widget = label;
 
 			ret = FALSE;
