@@ -27,7 +27,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-utils.h 5803 2007-08-15 00:08:37Z paolo $
+ * $Id: gedit-utils.h 5988 2007-10-28 14:44:53Z sfre $
  */
 
 #ifndef __GEDIT_UTILS_H__
@@ -81,9 +81,6 @@ GtkWidget	*gedit_dialog_add_button		(GtkDialog   *dialog,
 gchar		*gedit_utils_escape_underscores		(const gchar *text,
 							 gssize       length);
 
-gchar		*gedit_utils_escape_slashes		(const gchar *text,
-							 gssize       length);
-
 gchar		*gedit_utils_str_middle_truncate	(const gchar *string, 
 							 guint        truncate_length);
 
@@ -126,6 +123,10 @@ guint		 gedit_utils_get_current_workspace	(GdkScreen *screen);
 
 guint		 gedit_utils_get_window_workspace	(GtkWindow *gtkwindow);
 
+void		 gedit_utils_get_current_viewport	(GdkScreen    *screen,
+							 gint         *x,
+							 gint         *y);
+
 void		 gedit_utils_activate_url		(GtkAboutDialog *about,
 							 const gchar    *url,
 							 gpointer        data);
